/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia

  The DXC Framework is free software: you can redistribute it and/or modify it
  under the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation, either version 3 of the License, or (at your
  option) any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
  details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>
*/
#ifndef PROFLING_HPP
#define PROFLING_HPP

#include <typeinfo>
#include <DxcDefs.hpp>
#include <DataTypes/DxcData.hpp>

namespace Dxc
{
/**
 * @brief Data structure for DA process profiling information.
 */
class DXCAPI_EXPORT ProfilingData : public DxcData
{
public:
    /**
     * @brief Constructor.
     *
     * @param timestamp - message timestamp.
     * @param cpuTime - total process cpu time.
     * @param maxMem - peak memory usage.
     */
    ProfilingData(Timestamp timestamp, unsigned long cpuTime, unsigned long maxMem);

    /**
     * @brief Constructor without timestamp (sets timestamp to current time).
     *
     * @param cpuTime - total process cpu time.
     * @param maxMem - peak memory usage.
     */
    ProfilingData(unsigned long cpuTime, unsigned long maxMem);

    virtual ProfilingData* clone() const;

    virtual std::ostream &put(std::ostream &) const;

private:
    ProfilingData();

    unsigned long cpuTime_;
    unsigned long peakMemory_;
};
}

#endif
