/*
 DXC Framework (http://dx-competition.org/)
 Copyright 2008 David Garcia
 
 The DXC Framework is free software: you can redistribute it and/or modify it 
 under the terms of the GNU Lesser General Public License as published by the 
 Free Software Foundation, either version 3 of the License, or (at your 
 option) any later version. 

 This program is distributed in the hope that it will be useful, but WITHOUT 
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
 details. 

 You should have received a copy of the GNU Lesser General Public License 
 along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.api;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.util.HashMap;

/**
 * Access DXC configuration.
 * 
 * Reads keys and values stored in the DXC config file.
 */
public class DxcConfig {
    private static DxcConfig ref;

    private HashMap<String, String> myMap;

    /**
     * Loads DXC configuration and returns an instance of DxcConfig.
     */
    public static DxcConfig getInstance() throws Exception {
        if (ref == null) {
            ref = new DxcConfig();
        }
        return ref;
    }

    /**
     * Get the value of a key.
     * 
     * @param key
     *            key to return value of.
     * @return value pointed to by key
     * @throws Exception
     *             if key not found.
     */
    public String get(String key) throws Exception {
        String ret = myMap.get(key);
        if (ret == null) {
            throw new Exception("Config key not found.");
        }
        return ret;
    }

    private DxcConfig() throws FileNotFoundException, Exception {
        myMap = new HashMap<String, String>();
        String dxcHome = System.getenv("DXC_HOME");
        if (dxcHome == null) {
            throw new Exception(
                    "DXC_HOME is not set. Please set this environment variable.");
        }
        BufferedReader b = new BufferedReader(new FileReader(dxcHome
                + "/Dxc.cfg"));

        while (b.ready()) {
            String line = b.readLine();

            try {
                int m, n = line.indexOf(' ');
                String key = line.substring(0, n);

                n = line.indexOf('"');
                m = line.indexOf('"', n + 1);
                String val = line.substring(n + 1, m);

                myMap.put(key, val);
            } catch (Exception ex) {
            }
        }
    }

}
