/*
  DXC Framework (http://dx-competition.org/)
  Copyright 2008 David Garcia
  
  The DXC Framework is free software: you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by the 
  Free Software Foundation, either version 3 of the License, or (at your 
  option) any later version. 

  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
  FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more 
  details. 

  You should have received a copy of the GNU Lesser General Public License 
  along with this program. If not, see <http://www.gnu.org/licenses/> 
 */
package org.dxc.api.datatypes;

import java.io.OutputStream;
import java.io.PrintStream;

/**
 * Data structure for scenario information.
 */
public class ScenarioData extends DxcData {

    private String systemName;
    private String systemVersion;
    private String scenarioName;
    private String daName;
    private String daVers;
    private String frameworkVersion;
    private String notes;
    private long scenarioLength;

    /**
     * Constructor.
     * 
     * @param timestamp
     *            - message timestamp.
     * @param scenarioName
     *            - scenario name
     * @param systemName
     *            - system name
     * @param systemVersion
     *            - system version
     * @param daName
     *            - name of DA
     * @param daVersion
     *            - DA version
     * @param frameworkVersion
     *            - framework version
     * @param scenarioLength
     *            - length of scenario
     * @param notes
     *            - miscellaneous notes
     */
    public ScenarioData(long timestamp, String scenarioName, String systemName,
            String systemVersion, String daName, String daVersion,
            String frameworkVersion, long scenarioLength, String notes) {
        super(timestamp);
        this.scenarioName = scenarioName;
        this.daName = daName;
        this.daVers = daVersion;
        this.systemVersion = systemVersion;
        this.systemName = systemName;
        this.frameworkVersion = frameworkVersion;
        this.scenarioLength = scenarioLength;
        this.notes = notes;
    }

    /**
     * Constructs with timestamp set to current time.
     * 
     * @param scenarioName
     *            - scenario name
     * @param systemName
     *            - system name
     * @param systemVersion
     *            - system version
     * @param daName
     *            - name of DA
     * @param daVersion
     *            - DA version
     * @param frameworkVersion
     *            - framework version
     * @param scenarioLength
     *            - length of scenario
     * @param notes
     *            - miscellaneous notes
     */
    public ScenarioData(String scenarioName, String systemName,
            String systemVersion, String daName, String daVersion,
            String frameworkVersion, long scenarioLength, String notes) {
        super();
        this.scenarioName = scenarioName;
        this.daName = daName;
        this.daVers = daVersion;
        this.systemVersion = systemVersion;
        this.systemName = systemName;
        this.frameworkVersion = frameworkVersion;
        this.scenarioLength = scenarioLength;
        this.notes = notes;
    }

    public String getSystemName() {
        return systemName;
    }

    public String getScenarioName() {
        return scenarioName;
    }

    public String getDaName() {
        return daName;
    }

    public String getDaVersion() {
        return daVers;
    }

    public String getNotes() {
        return notes;
    }

    public long getscenarioLength() {
        return scenarioLength;
    }

    public String getSystemVersion() {
        return systemVersion;
    }

    public String getFrameworkVersion() {
        return frameworkVersion;
    }

    public OutputStream put(OutputStream os) {
        PrintStream out = new PrintStream(os);
        out.append("scenarioInfo @");
        out.append(Long.toString(this.getTimeStamp()));
        if (this.getSource() != null)
            out.append(" <" + this.getSource() + ">");
        out.append(" scenarioName = '" + this.scenarioName);
        out.append("', system = '" + this.systemName);
        out.append("', systemVersion = '" + this.systemVersion);
        out.append("', daName = '" + this.daName);
        out.append("', daVersion = '" + this.daVers);
        out.append("', frameworkVersion = '" + this.frameworkVersion);
        out.append("', scenarioLength = " + this.scenarioLength);
        out.append(", notes = '" + this.notes + "';\n");
        return out;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = super.hashCode();
        result = prime * result + ((daName == null) ? 0 : daName.hashCode());
        result = prime * result + getSource().hashCode();
        result = prime * result + ((daVers == null) ? 0 : daVers.hashCode());
        result = prime
                * result
                + ((frameworkVersion == null) ? 0 : frameworkVersion.hashCode());
        result = prime * result + ((notes == null) ? 0 : notes.hashCode());
        result = prime * result
                + (int) (scenarioLength ^ (scenarioLength >>> 32));
        result = prime * result
                + ((scenarioName == null) ? 0 : scenarioName.hashCode());
        result = prime * result
                + ((systemName == null) ? 0 : systemName.hashCode());
        result = prime * result
                + ((systemVersion == null) ? 0 : systemVersion.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (!super.equals(obj))
            return false;
        if (getClass() != obj.getClass())
            return false;
        ScenarioData other = (ScenarioData) obj;
        if (daName == null) {
            if (other.daName != null)
                return false;
        } else if (!daName.equals(other.daName))
            return false;
        if (daVers == null) {
            if (other.daVers != null)
                return false;
        } else if (!daVers.equals(other.daVers))
            return false;
        if (getSource() == null) {
            if (other.getSource() != null)
                return false;
        } else if (!getSource().equals(other.getSource()))
            return false;
        if (!(this.getTimeStamp() == other.getTimeStamp()))
            return false;
        if (frameworkVersion == null) {
            if (other.frameworkVersion != null)
                return false;
        } else if (!frameworkVersion.equals(other.frameworkVersion))
            return false;
        if (notes == null) {
            if (other.notes != null)
                return false;
        } else if (!notes.equals(other.notes))
            return false;
        if (scenarioLength != other.scenarioLength)
            return false;
        if (scenarioName == null) {
            if (other.scenarioName != null)
                return false;
        } else if (!scenarioName.equals(other.scenarioName))
            return false;
        if (systemName == null) {
            if (other.systemName != null)
                return false;
        } else if (!systemName.equals(other.systemName))
            return false;
        if (systemVersion == null) {
            if (other.systemVersion != null)
                return false;
        } else if (!systemVersion.equals(other.systemVersion))
            return false;
        return true;
    }
}