package org.dxc.api.datatypes;

import java.util.Map;
import java.util.Set;

/**
 * System catalog parser.
 * 
 * Provides a data structure for accessing information contained in a system's
 * XML catalog.
 */
public interface SystemCatalog {
    /**
     * The name of the system.
     */
    String getSystemName();

    /**
     * The set of component IDs the system contains.
     */
    Set<String> getComponentIDs();

    /**
     * The set of mode IDs of a given component
     * 
     * @param componentID
     *            component's ID
     */
    public Set<String> getModes(String componentID);

    /**
     * The set of mode IDs of a given component
     * 
     * @param componentID
     *            component's ID
     */
    public Set<String> getFaultModes(String componentID);

    /**
     * A map of the system's sensors and their probing cost, if any
     * 
     */
    public Map<String, Double> getSensorsAndCosts();

    /**
     * Test the validity of a componentID.
     * 
     * @param componentID
     *            component's ID
     */
    public boolean isComponentValid(String componentID);

    /**
     * Given a valid component, test the validity of a mode ID.
     * 
     * @param componentID
     *            component ID
     * @param modeID
     *            mode ID
     */
    public boolean isModeValid(String componentID, String modeID);

    /**
     * Given a valid component, test the validity of a mode ID.
     * 
     * @param componentID
     *            component ID
     * @param modeID
     *            mode ID
     */
    public boolean isFaultModeValid(String componentID, String modeID);

    /**
     * Returns the number of total component modes
     * 
     */
    public int getNumModes();

    /**
     * Returns the number of total component fault modes
     * 
     */
    public int getNumFaultModes();

    /**
     * Returns the number of components with no fault modes
     * 
     */
    public int getNumNoFaultComponents();

    boolean isFaultModeValid(Fault f);
}
